
# ZYXEL GS1920 SNMP

## Overview

This template is designed for [ZYXEL GS1920](https://www.zyxel.com/global/en/products/switch/8-24-48-port-gbe-smart-managed-switch-gs1920-series) monitoring by SNMP.

## Requirements

- Zabbix version: 6.0 and higher.

## Tested versions

This template has been tested on:

- [V4.80(ABMK.1) | 07/08/2024](https://download.zyxel.com/GS1920-48HPv2/firmware/GS1920-48HPv2_4.80(ABMK.1)C0_2.pdf)

### Macros used

|Name|Description|Default|
|----|-----------|-------|
|{$CPU.UTIL.CRIT}||`90`|
|{$SNMP.TIMEOUT}|The time interval for SNMP agent availability trigger expression.|`5m`|
|{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}|Triggers will be created only for interfaces whose description contains the value of this macro|`CHANGE_IF_NEEDED`|
|{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}|Filter of discoverable link types. 0 - Down link 1 - Cooper link 2 - Fiber link|`1\|2`|
|{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}|Filter to exclude discovered by link types.|`CHANGE_IF_NEEDED`|
|{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}|Filter by discoverable interface names.|`.*`|
|{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}|Filter to exclude discovered interfaces by name.|`CHANGE_IF_NEEDED`|

### Items

|Name|Description|Type|Key and additional info|
|----|-----------|----|-----------------------|
|ZYXEL GS1920: CPU utilization|MIB: ZYXEL-SYSTEM-MGMT-MIB|SNMP agent|zyxel.gs1920.cpuusage|
|ZYXEL GS1920: Hardware model name|MIB: RFC1213-MIB|SNMP agent|zyxel.gs1920.model|
|ZYXEL GS1920: Hardware serial number|MIB: ZYXEL-SYSTEM-MIB|SNMP agent|zyxel.gs1920.serialnumber|
|ZYXEL GS1920: Host name|MIB: RFC1213-MIB|SNMP agent|zyxel.gs1920.name|
|ZYXEL GS1920: MAC address|MIB: IF-MIB|SNMP agent|zyxel.gs1920.mac|
|ZYXEL GS1920: RAM utilization|MIB: ZYXEL-SYS-MEMORY-MIB|SNMP agent|zyxel.gs1920.ramusage|
|ZYXEL GS1920: Uptime|MIB: RFC1213-MIB|SNMP agent|zyxel.gs1920.uptime|

### Triggers

|Name|Description|Expression|Severity|Dependencies and additional info|
|----|-----------|----------|--------|--------------------------------|
|ZYXEL GS1920: Device has been replaced (new serial number received)|-|last(/ZYXEL GS1920 SNMP/zyxel.gs1920.serialnumber,#1)<>last(/ZYXEL GS1920 SNMP/zyxel.gs1920.serialnumber,#2) and length(last(/ZYXEL GS1920 SNMP/zyxel.gs1920.serialnumber))>0|Information|-|
|ZYXEL GS1920: has been restarted (uptime < 10m)|-|last(/ZYXEL GS1920 SNMP/zyxel.gs1920.uptime)<10m|Information|-|
|ZYXEL GS1920: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)|-|min(/ZYXEL GS1920 SNMP/zyxel.gs1920.cpuusage,5m)>{$CPU.UTIL.CRIT}|Warning|-|
|ZYXEL GS1920: No SNMP data collection|-|max(/ZYXEL GS1920 SNMP/zabbix[host,snmp,available],{$SNMP.TIMEOUT})=0|Warning|-|
|ZYXEL GS1920: Template does not match hardware|-|last(/ZYXEL GS1920 SNMP/zyxel.gs1920.model)<>"GS1920-48HP"|Information|-|

### Discovery rules

|Name|Description|Type|Key and additional info|
|----|-----------|----|-----------------------|
|Fan discovery|MIB: ZYXEL-HW-MONITOR-MIB|SNMP agent|zyxel.gs1920.fan.discovery|
|Interface discovery|-|SNMP agent|zyxel.gs1920.net.if.discovery|
|Temperature discovery|MIB: ZYXEL-HW-MONITOR-MIB|SNMP agent|zyxel.gs1920.temp.discovery|
|Voltage discovery|MIB: ZYXEL-HW-MONITOR-MIB|SNMP agent|zyxel.gs1920.volt.discovery|

### Item prototypes

|Name|Description|Type|Key and additional info|
|----|-----------|----|-----------------------|
|ZYXEL GS1920: Fan #{#SNMPINDEX}|MIB: ZYXEL-HW-MONITOR-MIB|SNMP agent|zyxel.gs1920.fan[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Administrative status|MIB: IF-MIB|SNMP agent|zyxel.gs1920.net.if.adminstatus[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Incoming broadcast packages|MIB: IF-MIB|SNMP agent|zyxel.gs1920.net.if.in.broadcastpkts[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Incoming multicast packages|MIB: IF-MIB|SNMP agent|zyxel.gs1920.net.if.in.multicastpkts[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Incoming traffic|MIB: IF-MIB|SNMP agent|zyxel.gs1920.net.if.in.traffic[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Incoming unicast packages|MIB: IF-MIB|SNMP agent|zyxel.gs1920.net.if.in.ucastpkts[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Incoming utilization|-|Calculated|zyxel.gs1920.net.if.in.util[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Interface description|MIB: ZYXEL-PORT-MIB|SNMP agent|zyxel.gs1920.net.if.name[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Interface name|MIB: IF-MIB|SNMP agent|zyxel.gs1920.net.if.descr[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Link speed|MIB: IF-MIB|SNMP agent|zyxel.gs1920.net.if.highspeed[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Link type|MIB: ZYXEL-PORT-MIB|SNMP agent|zyxel.gs1920.net.if.link_type[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Operational status|MIB: IF-MIB|SNMP agent|zyxel.gs1920.net.if.operstatus[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Outgoing broadcast packages|MIB: IF-MIB|SNMP agent|zyxel.gs1920.net.if.out.broadcastpkts[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Outgoing multicast packages|MIB: IF-MIB|SNMP agent|zyxel.gs1920.net.if.out.multicastpkts[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Outgoing traffic|MIB: IF-MIB|SNMP agent|zyxel.gs1920.net.if.out.traffic[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Outgoing unicast packages|MIB: IF-MIB|SNMP agent|zyxel.gs1920.net.if.out.ucastpkts[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Outgoing utilization|-|Calculated|zyxel.gs1920.net.if.out.util[{#SNMPINDEX}]|
|ZYXEL GS1920: Port {#SNMPINDEX}: Speed Duplex|MIB: ZYXEL-PORT-MIB|SNMP agent|zyxel.gs1920.net.if.speed_duplex[{#SNMPINDEX}]|
|ZYXEL GS1920: Temperature "{#ZYXEL.TEMP.ID}"|MIB: ZYXEL-HW-MONITOR-MIB|SNMP agent|zyxel.gs1920.temp[{#SNMPINDEX}]|
|ZYXEL GS1920: Nominal "{#ZYXEL.VOLT.NOMINAL}"|MIB: ZYXEL-HW-MONITOR-MIB|SNMP agent|zyxel.gs1920.volt[{#SNMPINDEX}]|
